@@ -179,8 +179,8 @@ class CcnetThreadedRpcClient(RpcClientBase):
     def add_emailuser(self, email, passwd, is_staff, is_active):
         pass
     
-    @searpc_func("int", ["string"])
-    def remove_emailuser(self, email):
+    @searpc_func("int", ["string", "string"])
+    def remove_emailuser(self, source, email):
         pass
     
     @searpc_func("int", ["string", "string"])
@@ -191,22 +191,34 @@ class CcnetThreadedRpcClient(RpcClientBase):
     def get_emailuser(self, email):
         pass
 
+    @searpc_func("object", ["string"])
+    def get_emailuser_with_import(self, email):
+        pass
+
     @searpc_func("object", ["int"])
     def get_emailuser_by_id(self, user_id):
         pass
 
-    @searpc_func("objlist", ["string", "int", "int"])
-    def get_emailusers(self, source, start, limit):
+    @searpc_func("objlist", ["string", "int", "int", "string"])
+    def get_emailusers(self, source, start, limit, status):
         pass
 
     @searpc_func("objlist", ["string", "string", "int", "int"])
     def search_emailusers(self, source, email_patt, start, limit):
         pass
+
+    @searpc_func("objlist", ["string", "int", "int"])
+    def search_ldapusers(self, keyword, start, limit):
+        pass
     
     @searpc_func("int64", ["string"])
     def count_emailusers(self, source):
         pass
 
+    @searpc_func("int64", ["string"])
+    def count_inactive_emailusers(self, source):
+        pass
+
     @searpc_func("objlist", ["string"])
     def filter_emailusers_by_emails(self):
         pass
@@ -248,7 +260,7 @@ class CcnetThreadedRpcClient(RpcClientBase):
         pass
 
     @searpc_func("int", ["string", "string", "string"])
-    def create_group(self, group_name, user_name, gtype=None):
+    def create_group(self, group_name, user_name, gtype):
         pass
 
     @searpc_func("int", ["int", "string", "string"])
@@ -288,7 +300,7 @@ class CcnetThreadedRpcClient(RpcClientBase):
         pass
 
     @searpc_func("objlist", ["int", "int", "string"])
-    def get_all_groups(self, start, limit, source=None):
+    def get_all_groups(self, start, limit, source):
         pass
     
     @searpc_func("object", ["int"])
@@ -315,30 +327,6 @@ class CcnetThreadedRpcClient(RpcClientBase):
     def set_group_creator(self, group_id, user_name):
         pass
 
-    @searpc_func("int", ["int", "string", "string"])
-    def group_share_repo(self, group_id, user_name, repo_id):
-        pass
-
-    @searpc_func("int", ["int", "string", "string"])
-    def group_unshare_repo(self, group_id, user_name, repo_id):
-        pass
-
-    @searpc_func("string", ["int"])
-    def get_group_repoids(self, group_id):
-        pass
-
-    @searpc_func("objlist", ["string"])
-    def get_group_my_share_repos(self, username):
-        pass
-
-    @searpc_func("objlist", ["string"])
-    def get_group_user_share_repos(self, username):
-        pass
-    
-    @searpc_func("string", ["string"])
-    def get_group_repo_share_from(self, repo_id):
-        pass
-
     @searpc_func("int", ["string", "string", "string"])
     def create_org(self, org_name, url_prefix, creator):
         pass
